# Navigating SAP LeanIX
Overview of the SAP LeanIX user interface.
The SAP LeanIX application offers a user-friendly interface that allows seamless navigation across its multiple features. The application's main navigation bar located at the top of the screen provides quick access to key items such as dashboards, inventory, reports, diagrams, and collaboration features. Furthermore, from the navigation bar, you can search for fact sheets, view product updates, access various support and enablement resources, and navigate to your personal and workspace settings.
**Tip**
To get an overview of the user interface (UI) and the key features in SAP LeanIX, in the Help menu indicated by a question mark icon, select Start Help Tour.
![Navigating SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275745d97a4410148669e5379ec4d8c9_LowRes.gif)
Navigating SAP LeanIX
In the following table, you can find an overview of the main UI elements within the SAP LeanIX application.
UI Element | Overview | Additional Information and Resources
---|---|---
Dashboards tab |  Your entry point to the SAP LeanIX workspace is the dashboard. The dashboard offers a centralized overview of important metrics, performance indicators, and relevant information within a workspace. It comes with several predefined dashboard panels that provide real-time views of data and user reports, charts, and widgets.  The dashboard presents information in a visually appealing way. The primary purpose of a dashboard is to help stakeholders monitor the performance of the architecture, communicate effectively with each other, and make better, data-driven decisions. |  [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.")
Inventory tab |  The inventory is a centralized repository that stores and organizes information about all architectural elements in the form of fact sheets. Each architectural object, such as application, business capability, organization, and more, is represented by fact sheets that store relevant information. The inventory is the place where you can create and edit fact sheets. You can search and filter fact sheets based on your requirements using the left-side pane. You can navigate to a fact sheet by selecting it. |  [Inventory](https://help.sap.com/docs/leanix/ea/inventory?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory is your centralized repository for managing and documenting enterprise architecture objects. You create, edit, and organize fact sheets to maintain an accurate depiction of your IT landscape. It is the go-to place for anyone seeking information from the fact sheets.")
Reports tab | Reports allow you to generate default and custom visual reports based on your enterprise architecture data. These reports provide insights, analysis, and visualization of the architecture, enabling data-driven decision-making and effective communication. |  [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD)
Diagrams tab | Diagrams are advanced features typically used by enterprise architects to create visualizations of data flows and to visualize complex architecture by breaking it down into smaller scopes. Like reports, diagrams are also a great tool for effectively presenting data to various stakeholders. |  [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD)
More menu |  From the More menu, you can access the following:
  * To-dos
  * Surveys
  * Presentations
  * Architecture decisions
  * Software bill of materials (SBOM) explorer
  * Reference catalog
  * Portals
  * SAP LeanIX Store

|
  * [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD "To-dos facilitate task delegation, collaboration, and governance and can be used to ensure data integrity and quality through transparent task management.")
  * [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.")
  * [Presentations](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD "Use presentations to share enterprise architecture insights from reports and diagrams with your organization, without the need to export data to external presentation tools.")
  * [Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD "Document and manage enterprise architecture decisions directly within SAP LeanIX, keeping all architecture-related information in one place.")
  * [SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "The SBOM explorer helps you understand your open-source libraries' usage, manage them, track them during cybersecurity incidents, and quickly take action to address risks and compliance issues.")
  * [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.")
  * [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")
  * [Downloading Reports from the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Download custom reports from the SAP LeanIX Store and make them available to all workspace users.")
  * [Publishing Custom Reports on the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how the SAP LeanIX Store works and how to publish your custom reports.")


Search field | This field provides a full-text search feature that allows you to quickly find a fact sheet within the inventory or directly navigate to a specific fact sheet without opening the inventory. |  [Searching and Filtering in the Inventory](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory?locale=en-US&state=PRODUCTION&version=CLOUD "Searching and filtering in the inventory helps efficiently manage your data. Learn how to quickly find fact sheets, apply filters, manage filters, and save search results for future access.")
Workspace views list | Use workspace views configured by admins to limit the scope of displayed information and focus on your current tasks. |  [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views?locale=en-US&state=PRODUCTION&version=CLOUD "Use workspace views configured by admins to limit the scope of displayed information and focus on your current tasks.")
Product updates (megaphone icon) | In this section, you can find important announcements related to product updates, changes, and other communications from SAP LeanIX. |  [SAP LeanIX Product Updates![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fupdates.leanix.net%2F%3Fcategories%3Dcat_tO5bPYSf0HyDF%252Ccat_sFZ4xTVt963AL%252Ccat_aue3NRCGHzHrb "https://updates.leanix.net/?categories=cat_tO5bPYSf0HyDF%2Ccat_sFZ4xTVt963AL%2Ccat_aue3NRCGHzHrb")
Help menu (question mark icon) |  From the Help menu, you can access the following resources:
  * SAP LeanIX Product Roadmap where you can provide feedback and suggest product ideas
  * SAP Learning offering training resources for SAP LeanIX
  * SAP LeanIX Community where you can connect with other users to share knowledge and best practices
  * Product documentation and getting started guide
  * Developer tools
  * Technical information about the SAP LeanIX application, such as build details, status, licenses, and more
  * Data Privacy and Cookie Policy documents

|
  * [SAP LeanIX Product Roadmap![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2F "https://roadmap.leanix.net/")
  * [SAP LeanIX Community![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.leanix.net%2F "https://community.leanix.net/")
  * [SAP Learning![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fproducts%2Fbusiness-transformation-management%2Fleanix "https://learning.sap.com/products/business-transformation-management/leanix")
  * [Data Privacy Statement](https://help.sap.com/docs/leanix/ea/data-privacy-statement-sap-leanix-workspace?locale=en-US&state=PRODUCTION&version=CLOUD "Data privacy statement for SAP LeanIX workspaces.")
  * [Cookie and Local Storage Policy](https://help.sap.com/docs/leanix/ea/cookies-and-local-storage-policy-sap-leanix-workspace?locale=en-US&state=PRODUCTION&version=CLOUD "Cookies and local storage policy for SAP LeanIX workspaces.")


User profile menu |  From the user profile menu, you can access the following resources:
  * Your profile settings where you can configure your notification preferences, set a new password, and edit your profile information
  * Portals to which you have access, if configured
  * SAP LeanIX Store that provides access to custom reports and other resources
  * Options to switch a workspace or sign out from the workspace

As an admin user, in addition to the specified options, you can do the following from the user profile menu:
  * Navigate to the workspace administration area
  * Temporarily switch your user role
  * Invite new users to the workspace

|
  * [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.")
  * [User Profile](https://help.sap.com/docs/leanix/ea/user-profile?locale=en-US&state=PRODUCTION&version=CLOUD "Manage your user profile settings. Change or reset your password if needed.")
  * [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")
  * [SAP LeanIX Store![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fbrowse "https://store.leanix.net/browse")
  * [Workspace Administration](https://help.sap.com/docs/leanix/ea/workspace-administration?locale=en-US&state=PRODUCTION&version=CLOUD "The workspace administration area is a centralized hub for managing and customizing your workspace. As an admin, you can adjust workspace settings to best suit the needs of your team.")


Support button in the lower-right corner | If you need assistance while using SAP LeanIX, you can contact support by clicking the Support button located in the lower-right corner of the screen. A workspace admin can configure support channels for their organization. | [Contact Support](https://help.sap.com/docs/leanix/ea/contact-support?locale=en-US&state=PRODUCTION&version=CLOUD "If you encounter issues, have questions, or need assistance with SAP LeanIX, our support team is here to help. You can contact support directly within SAP LeanIX or submit a request in the SAP for Me portal.")


